<?php

    /**
     * ReduxFramework Barebones Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "photofolio_options";
    
    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__( 'Photofolio Options', 'photofolio' ),
        'page_title'           => esc_html__( 'Photofolio Options', 'photofolio' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-admin-generic',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'forced_dev_mode_off' => true,
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'system_info'          => false,
        // REMOVE

        //'compiler'             => true,

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'light',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
    

    
    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf('<p>Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: <strong>$%1$s</strong></p>', $v );
    } else {
        $args['intro_text'] = wp_kses_post(__( '<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'photofolio' ));
    }

    // Add content after the form.
    $args['footer_text'] = wp_kses_post(__( '<p>This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.</p>', 'photofolio' ));

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Theme Information 1', 'photofolio' ),
            'content' => wp_kses_post(__( '<p>This is the tab content, HTML is allowed.</p>', 'photofolio' ))
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_html__( 'Theme Information 2', 'photofolio' ),
            'content' => wp_kses_post(__( '<p>This is the tab content, HTML is allowed.</p>', 'photofolio' ))
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = wp_kses_post(__( '<p>This is the sidebar content, HTML is allowed.</p>', 'photofolio' ));
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */
    
    
    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // -> START Basic Fields
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'General Settings', 'photofolio' ),
        'id'     => 'general',
        'desc'   => '',
        'icon'   => 'el el-icon-cogs',
        'fields' => array(
             array(
                'id' => 'favicon',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('Custom Favicon', 'photofolio'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('Upload your Favicon.', 'photofolio'),
                'subtitle' => '',
                'default' => array('url' => ''),
            ),
            array(
                'id' => 'logo',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('Logo', 'photofolio'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('Upload your logo.', 'photofolio'),
                'subtitle' => '',
                'default' => array('url' => get_template_directory_uri().'/images/logo-black.png'),
            ),
            array(
                'id' => 'logo_t',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('Logo For transparent header', 'photofolio'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('Upload your logo.', 'photofolio'),
                'subtitle' => '',
                'default' => array('url' => get_template_directory_uri().'/images/logo.png'),
            ),
            array(
                        'id' => 'apple_icon',
                        'type' => 'media',
                        'url' => true,
                        'title' => esc_html__('Apple Touch Icon', 'photofolio'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => esc_html__('Upload your Apple touch icon 57x57.', 'photofolio'),
                        'subtitle' => '',
                        'default' => array('url' => ''),
                    ),
                    array(
                        'id' => 'apple_icon_57',
                        'type' => 'media',
                        'url' => true,
                        'title' => esc_html__('Apple Touch Icon 57x57', 'photofolio'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => esc_html__('Upload your Apple touch icon 57x57.', 'photofolio'),
                        'subtitle' => '',
                        'default' => array('url' => ''),
                    ),
                    array(
                        'id' => 'apple_icon_72',
                        'type' => 'media',
                        'url' => true,
                        'title' => esc_html__('Apple Touch Icon 72x72', 'photofolio'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => esc_html__('Upload your Apple touch icon 72x72.', 'photofolio'),
                        'subtitle' => '',
                        'default' => array('url' => ''),
                    ),
                    array(
                        'id' => 'apple_icon_114',
                        'type' => 'media',
                        'url' => true,
                        'title' => esc_html__('Apple Touch Icon 114x114', 'photofolio'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => esc_html__('Upload your Apple touch icon 114x114.', 'photofolio'),
                        'subtitle' => '',
                        'default' => array('url' => ''),
                    ),
        )
    ) );
    
    Redux::setSection( $opt_name,array(
        'icon'      => 'el el-magic',
        'title'     => esc_html__('Styling Options', 'photofolio'),
        'fields'    => array(
            
            
            array(
                'id' => 'body-font2',
                'type' => 'typography',
                'output' => array('body'),
                'title' => esc_html__('Body Font', 'photofolio'),
                'subtitle' => esc_html__('Specify the body font properties.', 'photofolio'),
                'google' => true,
                'default' => array(
                    'color' => '#888',
                    'font-size' => '13px',
                    'line-height' => '20px',
                    'font-family' => "Roboto",
                    'font-weight' => '400',
                ),
            ),
            
           
             array(
                'id'        => 'custom-css',
                'type'      => 'ace_editor',
                'title'     => esc_html__('Custom CSS Code', 'photofolio'),
                'subtitle'  => esc_html__('Paste your CSS code here.', 'photofolio'),
                'mode'      => 'css',
                'theme'     => 'monokai',
                'desc'      => 'Possible modes can be found at <a href="http://ace.c9.io" target="_blank">http://ace.c9.io/</a>.',
                'default'   => "#header{\nmargin: 0 auto;\n}"
            ),
                 
           
        )
    ));
     Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Blog Settings', 'photofolio' ),
        'id'         => 'blog_settings',
        'desc'       => '',
        'icon'   => 'el el-edit',
        'fields'     => array(

           array(
                'id'        => 'blog_layout',
                'type'      => 'select',
                'title'     => esc_html__('Default  Blog Layout', 'photofolio'),
                'subtitle'  => esc_html__('Select  blog layout.', 'photofolio'),
                'options'   => array(
                                        'standard' => 'Default', 
                                        'no-sidebar' => 'Without Sidebar', 
                                    ),
                'default'   => 'standard',
            ), 
           array(
                'id' => 'blog_title',
                'type' => 'text',
                'title' => 'blog_title',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'BLog',
            ),
           array(
                'id' => 'single_title',
                'type' => 'text',
                'title' => 'single_title',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'Single Post',
            ),
           array(
                'id'       => 'blog_thumbnail',
                'type'     => 'switch',
                'title'    => esc_html__( 'Turn On/Off Featured image on Single Post', 'photofolio' ),
                'subtitle' => '',
                'default'  => true,
            ),
           array(
                'id'       => 'blog_author',
                'type'     => 'switch',
                'title'    => esc_html__( 'Turn On/Off author section on Single Post', 'photofolio' ),
                'subtitle' => '',
                'default'  => true,
            ),
           
        )
    ) );
     Redux::setSection( $opt_name, array(
        'title'      => esc_html__( '404 Settings', 'photofolio' ),
        'id'         => '404_settings',
        'desc'       => '',
        'icon'   => 'el el-warning-sign',
        'fields'     => array(
           
           array(
                'id'       => '404-editor',
                'type'     => 'editor',
                'title'    => esc_html__( '404 Error Content', 'photofolio' ),
                'subtitle' => '',
                'default'  => "<span>404</span>
<h1>That Page Can't Be Found</h1>
<p>It looks like nothing was found at this location. Maybe try a search?</p>",
            ),
           array(
                'id' => '404_bg',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('404 Content Background Image', 'photofolio'),
                'compiler' => 'true',
                
                'desc' => esc_html__('404 content background.', 'photofolio'),
                'subtitle' => '',
                'default' => array('url' => 'http://placehold.it/1600x1200'),
            ),

        )
    ) );

     Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Comming Soon Settings', 'photofolio' ),
        'id'         => 'comming_settings',
        'desc'       => '',
        'icon'   => 'el el-time',
        'fields'     => array(
           array(
                'id' => 'coming_email',
                'type' => 'text',
                'title' => esc_html__('Your Email', 'photofolio'),
                'desc'     => '',
                'default' => 'Userthemes@gmail.com',
            ), 
           array(
                'id' => 'coming_phone',
                'type' => 'text',
                'title' => esc_html__('Your Phone Number', 'photofolio'),
                'desc'     => '',
                'default' => '0707-567-899',
            ),
           array(
                'id' => 'coming_date',
                'type' => 'text',
                'title' => esc_html__('Coming Date', 'photofolio'),
                'desc'     => 'Example "01/26/2017 12:00:00"',
                'default' => '01/26/2017 12:00:00',
            ),
           array(
                'id'       => 'comming-editor',
                'type'     => 'editor',
                'title'    => esc_html__( '404 Error Content', 'photofolio' ),
                'subtitle' => '',
                'default'  => '<h1>LAUNCHING SOON</h1>
<span>We are currently working on awesome new site. Stay tuned!</span>',
            ),
           
           array(
                'id' => 'coming_bg',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('Coming Content Background Image', 'photofolio'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('Coming content background.', 'photofolio'),
                'subtitle' => '',
                'default' => array('url' => ''),
            ),

        )
    ) );

     Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Header Settings', 'photofolio' ),
        'id'     => 'header',
        'desc'   => '',
        'icon'   => 'el el-lines',
        'fields' => array(
             array(
                'id'       => 'open_menu',
                'type'     => 'switch',
                'title'    => esc_html__( 'Open Menu as Default', 'photofolio' ),
                'subtitle' => '',
                'default'  => false,
            ),
              array(
                'id'        => 'header_style',
                'type'      => 'select',
                'title'     => esc_html__('Main Header Style Layout', 'photofolio'),
                'subtitle'  => esc_html__('Select header style layout.', 'photofolio'),
                'options'   => array(
                                        'standard' => 'Default', 
                                        'vertical' => 'Vertical', 
                                    ),
                'default'   => 'standard',
            ), 
            array(
                'id' => 'beadcrumb_bg',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('Page Heading default background', 'photofolio'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('Upload your background image.', 'photofolio'),
                'subtitle' => '',
                'default' => array('url' => ''),
            ),
            array(
                'id' => 'menu_bg',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('Megamenu Background image', 'photofolio'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('Upload your background image.', 'photofolio'),
                'subtitle' => '',
                'default' => array('url' => ''),
            ),
        )
    ) );
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Footer Settings', 'photofolio' ),
        'id'     => 'footer',
        'desc'   => '',
        'icon'   => 'el el-th',
        'fields' => array(
             array(
                'id'       => 'footer-widgets',
                'type'     => 'select',
                'title'    => esc_html__( 'Turn ON footer widget area', 'photofolio' ),
                'subtitle' => '',
                'desc'     => '',
                //Must provide key => value pairs for select options
                'options'  => array(
                    'no' => 'No',
                    'yes' => 'Yes',
                ),
                'default'  => 'yes'
            ),array(
                'id' => 'footer-text',
                'type' => 'editor',
                'title' => esc_html__('Footer Text', 'photofolio'),
                'subtitle' => esc_html__('Copyright Text', 'photofolio'),
                'default' => '&copy; Copyright 2016. "photofolio" by Nunforest. All rights reserved.',
            ),
        )
    ) );
    Redux::setSection( $opt_name, array(
        'icon' => 'el el-dribbble',
        'title' => esc_html__('Social Settinigs', 'photofolio'),
        'fields' => array(
            array(
                'id' => 'facebook',
                'type' => 'text',
                'title' => esc_html__('Facebook Url', 'photofolio'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '#',
            ),
            array(
                'id' => 'twitter',
                'type' => 'text',
                'title' => esc_html__('Twitter Url', 'photofolio'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '#',
            ),
            array(
                'id' => 'google',
                'type' => 'text',
                'title' => esc_html__('Google+ Url', 'photofolio'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '#',
            ),
            array(
                'id' => 'instagram',
                'type' => 'text',
                'title' => esc_html__('Instagram Url', 'photofolio'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '#',
            ),
           
            array(
                'id' => 'pinterest',
                'type' => 'text',
                'title' => esc_html__('Pinterest Url', 'photofolio'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '#'
            ),
            array(
                'id' => 'flickr',
                'type' => 'text',
                'title' => esc_html__('Flickr Url', 'photofolio'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '#'
            ),
        )
    )
    );
    

    /*
     * <--- END SECTIONS
     */