<?php
/**
 * Related Products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/related.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     1.6.4
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $post, $product, $woocommerce_loop;

if ( empty( $product ) || ! $product->exists() ) {
	return;
}

if ( ! $related = $product->get_related( $posts_per_page ) ) {
	return;
}

$args = apply_filters( 'woocommerce_related_products_args', array(
	'post_type'            => 'product',
	'ignore_sticky_posts'  => 1,
	'no_found_rows'        => 1,
	'posts_per_page'       => 6,
	'orderby'              => $orderby,
	'post__in'             => $related,
	'post__not_in'         => array( $product->id )
) );

$products                    = new WP_Query( $args );
$woocommerce_loop['name']    = 'related';
$woocommerce_loop['columns'] = apply_filters( 'woocommerce_related_products_columns', $columns );

if ( $products->have_posts() ) : ?>

	<section class="shop-section related-products">
				<div class="container">
					<div class="shop-box">

		<h1><?php esc_html_e( 'Related Products', 'photofolio' ); ?></h1>
		<div class="inner-shop-box owl-wrapper">
							<div class="owl-carousel" data-num="4">
		

			<?php while ( $products->have_posts() ) : $products->the_post(); ?>
				<?php $new_product = new WC_Product( get_the_ID() ); ?>
				<div class="shop-post">
					<div class="shop-gal">
						<?php do_action( 'woocommerce_before_shop_loop_item_title' ); ?>
						<div class="hover-box">
							<div class="inner-hover">
								<?php
									$handler = apply_filters( 'woocommerce_add_to_cart_handler', $new_product->product_type, $new_product );
									switch ( $handler ) {
									case "variable" :
										$add_cart = get_permalink();
									break;
									case "grouped" :
										$add_cart = get_permalink();
									break;
									case "external" :
										 $add_cart = get_permalink();
									break;
									default :
										if ( $new_product->is_purchasable() ) {
											 $add_cart = esc_url( $new_product->add_to_cart_url() );
										} else {
											 $add_cart = get_permalink();
										}
									break;
								}
								?>
								<a rel="nofollow" href="<?php echo esc_url($add_cart); ?>" data-quantity="1" data-product_id="<?php the_ID(); ?>" data-product_sku="<?php echo esc_attr($new_product->get_sku()); ?>" class="product_type_<?php echo esc_attr($new_product->product_type); ?> add_to_cart_button ajax_add_to_cart"><?php esc_html_e('Add to Cart','photofolio'); ?></a><br>
							</div>
						</div>
					</div>
					<div class="post-content">
						<span><?php echo $new_product->get_categories( ', ', '' . _n( '', '', sizeof( get_the_terms( get_the_ID(), 'product_cat' ) ), 'woocommerce' ) . ' ', '' ); ?></span>
						<h2><a href="<?php the_permalink();?>"><?php the_title(); ?></a></h2>
						<?php do_action( 'woocommerce_after_shop_loop_item_title' ); ?>
					</div>
				</div>

			<?php endwhile; // end of the loop. ?>

		
		</div></div>
	</div></div></section>

<?php endif;

wp_reset_postdata();
